;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "comment-dwim-2" "20241219.1643"
  "An all-in-one comment command to rule them all."
  '((emacs "28.1"))
  :url "https://github.com/remyferre/comment-dwim-2"
  :commit "6ab75d0a690f0080e9b97c730aac817d04144cd0"
  :revdesc "6ab75d0a690f"
  :keywords '("convenience" "tools")
  :authors '(("Rémy Ferré" . "dev@remyferre.net"))
  :maintainers '(("Rémy Ferré" . "dev@remyferre.net")))
